package Sah::Schemas::App::cryp;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-03-02'; # DATE
our $DIST = 'Sah-Schemas-App-cryp'; # DIST
our $VERSION = '0.005'; # VERSION

1;
# ABSTRACT: Various Sah schemas for the 'cryp' app family

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::App::cryp - Various Sah schemas for the 'cryp' app family

=head1 VERSION

This document describes version 0.005 of Sah::Schemas::App::cryp (from Perl distribution Sah-Schemas-App-cryp), released on 2020-03-02.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-App-cryp>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-App-cryp>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-App-cryp>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

L<App::cryp> and C<App::cryp::*>

L<Sah::Schemas::CryptoCurrency>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
